/*
 * Copyright (c) 2024 NVIDIA CORPORATION & AFFILIATES. All rights reserved.
 *
 * This software is available to you under a choice of one of two
 * licenses.  You may choose to be licensed under the terms of the GNU
 * General Public License (GPL) Version 2, available from the file
 * COPYING in the main directory of this source tree, or the
 * OpenIB.org BSD license below:
 *
 *     Redistribution and use in source and binary forms, with or
 *     without modification, are permitted provided that the following
 *     conditions are met:
 *
 *      - Redistributions of source code must retain the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer.
 *
 *      - Redistributions in binary form must reproduce the above
 *        copyright notice, this list of conditions and the following
 *        disclaimer in the documentation and/or other materials
 *        provided with the distribution.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS
 * BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN
 * ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN
 * CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 *
 */

/*
 * Abstract:
 *	Module for planarization feature
 *
 * Author:
 *	Gull Sharon, NVIDIA
 */

#ifndef OSM_PLANARIZED_H
#define OSM_PLANARIZED_H

#include <iba/ib_types.h>
#include <complib/cl_types_osd.h>
#include <opensm/osm_subnet.h>
#include <opensm/osm_log.h>

/****f* OpenSM: Planarized/osm_aport_need_update
* NAME
*	osm_aport_need_update
*
* DESCRIPTION
*	Check whether any physp in the aport needs update
*
* SYNOPSIS
*/
boolean_t osm_aport_need_update(IN osm_aport_t * p_aport);
/*
* PARAMETERS
*	p_aport
*		Pointer to aport to check.
*
* RETURN VALUES
*	Whether any physp in the aport needs update.
*
* SEE ALSO
*********/

/****s* OpenSM: Planarized/osm_planarized_data_t
* NAME
*	osm_planarized_data_t
*
* DESCRIPTION
*	This object represents planarization data which is relevant for a osm_port_t object.
*
* SYNOPSIS
*/
typedef struct osm_planarized_data_t {
	ib_end_port_plane_filter_config_t subn_end_port_plane_filter_config;
} osm_planarized_data_t;
/*
* FIELDS
*	subn_end_port_plane_filter_config
*		The EndPortPlaneFilterConfig MAD content configured on the port in the subnet.
*
* SEE ALSO
********/

/****f* OpenSM: Planarized/osm_set_end_port_plane_filter_config
* NAME
*	osm_set_end_port_plane_filter_config
*
* DESCRIPTION
*	Calculate and send EndPortPlaneFilterConfig to HCAs.
*
* SYNOPSIS
*/
void osm_set_end_port_plane_filter_config(IN cl_map_item_t * p_item, IN void * context);
/*
* PARAMETERS
*	p_item
*		A cl_map_item_t representing an osm_port_t to set EndPortPlaneFilterConfig on.
*
*	context
*		A void pointer representing a pointer to the SM.
*
* RETURN VALUES
*
* SEE ALSO
*********/

#endif				/* ifndef OSM_PLANARIZED_H */
